append_chunks: Append chunks to flextable content

View source: R/append_chunk.R

append_chunksR Documentation

Append chunks to flextable content

Description

append chunks (for example chunk as_chunk()) in a flextable.

Usage

append_chunks(x, ..., i = NULL, j = NULL, part = "body")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

...

chunks to be appened, see as_chunk(), gg_chunk() and other chunk elements for paragraph.

i

row selector, see section Row selection with the i parameter in <Selectors in flextable>.

j

column selector, see section Column selection with the j parameter in <Selectors in flextable>.

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' is not allowed by the function.

See Also

as_chunk(), as_sup(), as_sub(), colorize()

Other functions to compose cell content: as_paragraph(), compose(), footnote(), labelizor(), prepend_chunks(), void()

Examples

library(flextable)
img.file <- file.path(R.home("doc"), "html", "logo.jpg")

ft_1 <- flextable(head(cars))

ft_1 <- append_chunks(ft_1,
  # where to append
  i = c(1, 3, 5),
  j = 1,
  # what to append
  as_chunk(" "),
  as_image(src = img.file, width = .20, height = .15)
)
ft_1 <- set_table_properties(ft_1, layout = "autofit")
ft_1

flextable documentation built on June 2, 2026, 9:08 a.m.