| args_x_j_part_no_all | R Documentation |
internal utils for roxygen tags reuse
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
j |
column selector, see section Column selection with the |
part |
part selector, see section Part selection with the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.