| as_flextable | R Documentation |
This is a convenient function to let users create flextable bindings from any objects. Users should consult documentation of corresponding method to understand the details and see what arguments can be used.
as_flextable(x, ...)
x |
object to be transformed as flextable |
... |
arguments for custom methods |
Other flextable constructors:
flextable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.