dim.flextable: Get column widths and row heights of a flextable

View source: R/flextable_sizes.R

dim.flextableR Documentation

Get column widths and row heights of a flextable

Description

returns widths and heights for each table columns and rows. Values are expressed in inches.

Usage

## S3 method for class 'flextable'
dim(x)

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

See Also

Other functions for flextable size management: autofit(), dim_pretty(), fit_columns(), fit_to_width(), flextable_dim(), height(), hrule(), ncol_keys(), nrow_part(), set_table_properties(), width()

Examples

ftab <- flextable(head(iris))
dim(ftab)

flextable documentation built on June 2, 2026, 9:08 a.m.