| hline_bottom | R Documentation |
hline_bottom() draws a horizontal line at the very bottom
of a table part. It does not accept a row selector i because
it always targets the last row.
Unlike hline(), which adds inner lines below arbitrary rows,
hline_bottom() is meant for the outer bottom edge of a part.
hline_bottom(x, j = NULL, border = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
j |
column selector, see section Column selection with the |
border |
border properties defined by a call to
|
part |
part selector, see section Part selection with the |
Other borders management:
border_inner(),
border_inner_h(),
border_inner_v(),
border_outer(),
border_remove(),
hline(),
hline_top(),
surround(),
vline(),
vline_left(),
vline_right()
library(officer)
big_border <- fp_border(color = "orange", width = 3)
ft <- flextable(head(iris))
ft <- border_remove(x = ft)
# add a thick line at the bottom of the body
ft <- hline_bottom(ft, part = "body", border = big_border)
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.