View source: R/flextable_sizes.R
| hrule | R Documentation |
hrule() controls whether row heights are automatic,
minimum or fixed. This only affects Word and PowerPoint
outputs; it has no effect on HTML or PDF.
"auto" (default): the row height adjusts to fit the
content; any value set by height() is ignored.
"atleast": the row is at least as tall as the value
set by height(), but can grow if the content is taller.
"exact": the row is exactly the height set by
height(); content that overflows is clipped.
For PDF see the ft.arraystretch chunk option.
hrule(x, i = NULL, rule = "auto", part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
rule |
specify the meaning of the height. Possible values are "atleast" (height should be at least the value specified), "exact" (height should be exactly the value specified), or the default value "auto" (height is determined based on the height of the contents, so the value is ignored). |
part |
part selector, see section Part selection with the |
Other functions for flextable size management:
autofit(),
dim.flextable(),
dim_pretty(),
fit_columns(),
fit_to_width(),
flextable_dim(),
height(),
ncol_keys(),
nrow_part(),
set_table_properties(),
width()
ft_1 <- flextable(head(iris))
ft_1 <- width(ft_1, width = 1.5)
ft_1 <- height(ft_1, height = 0.75, part = "header")
ft_1 <- hrule(ft_1, rule = "exact", part = "header")
ft_1
ft_2 <- hrule(ft_1, rule = "auto", part = "header")
ft_2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.