information_data_cell: Get cell-level information from a flextable

View source: R/read_structure.R

information_data_cellR Documentation

Get cell-level information from a flextable

Description

This function takes a flextable object and returns a data.frame containing information about each cell within the flextable. The data.frame includes details about formatting properties and position within the row and column.

Usage

information_data_cell(x)

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

Value

a data.frame containing information about cells:

  • formatting properties,

  • part (.part), row (.row_id) and column (.col_id).

don't use this

These data structures should not be used, as they represent an interpretation of the underlying data structures, which may evolve over time.

They are exported to enable two packages that exploit these structures to make a transition, and should not remain available for long.

See Also

Other table data extraction: information_data_chunk(), information_data_paragraph()

Examples

ft <- as_flextable(iris)
x <- information_data_cell(ft)
head(x)

flextable documentation built on June 2, 2026, 9:08 a.m.