| italic | R Documentation |
Change the font decoration of selected rows and columns of a flextable.
italic(x, i = NULL, j = NULL, italic = TRUE, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
italic |
boolean value |
part |
part selector, see section Part selection with the |
Other formatting shortcuts:
align(),
bg(),
bold(),
color(),
empty_blanks(),
font(),
fontsize(),
highlight(),
keep_with_next(),
line_spacing(),
padding(),
rotate(),
style(),
tab_settings(),
valign()
ft <- flextable(head(mtcars))
ft <- italic(ft, italic = TRUE, part = "header")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.