| line_spacing | R Documentation |
Change the line spacing of selected rows and columns of a flextable.
line_spacing(x, i = NULL, j = NULL, space = 1, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
space |
space between lines of text; 1 is single line spacing, 2 is double line spacing. |
part |
part selector, see section Part selection with the |
Other formatting shortcuts:
align(),
bg(),
bold(),
color(),
empty_blanks(),
font(),
fontsize(),
highlight(),
italic(),
keep_with_next(),
padding(),
rotate(),
style(),
tab_settings(),
valign()
ft <- flextable(head(mtcars)[, 3:6])
ft <- line_spacing(ft, space = 1.6, part = "all")
ft <- set_table_properties(ft, layout = "autofit")
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.