merge_at: Merge flextable cells into a single one

View source: R/merge_flextable.R

merge_atR Documentation

Merge flextable cells into a single one

Description

Merge flextable cells into a single one. All rows and columns must be consecutive.

Usage

merge_at(x, i = NULL, j = NULL, part = "body")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

i

row selector, see section Row selection with the i parameter in <Selectors in flextable>.

j

column selector, see section Column selection with the j parameter in <Selectors in flextable>.

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' is not allowed by the function.

See Also

Other cell merging functions: merge_h(), merge_h_range(), merge_none(), merge_v()

Examples

ft_merge <- flextable(head(mtcars), cwidth = .5)
ft_merge <- merge_at(ft_merge, i = 1:2, j = 1:2)
ft_merge

flextable documentation built on June 2, 2026, 9:08 a.m.