note_docx_images: internal utils for roxygen tags reuse

note_docx_imagesR Documentation

internal utils for roxygen tags reuse

Description

internal utils for roxygen tags reuse

Note

This chunk option requires package officedown in a R Markdown context with Word output format. With Quarto (format: docx) or rmarkdown::word_document(), the resulting file must be repaired with repair_docx().

PowerPoint cannot mix images and text in a paragraph, images are removed when outputing to PowerPoint format.


flextable documentation built on July 7, 2026, 5:06 p.m.