Skip to contents

returns the number of lines in a part of flextable.

Usage

nrow_part(x, part = "body")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' can be used.

See also

Examples

library(flextable)
ft <- qflextable(head(cars))
nrow_part(ft, part = "body")
#> [1] 6