| padding | R Documentation |
Change the padding of selected rows and columns of a flextable.
padding(
x,
i = NULL,
j = NULL,
padding = NULL,
padding.top = NULL,
padding.bottom = NULL,
padding.left = NULL,
padding.right = NULL,
part = "body"
)
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
padding |
padding (shortcut for top, bottom, left and right), unit is pts (points). |
padding.top |
padding top, unit is pts (points). |
padding.bottom |
padding bottom, unit is pts (points). |
padding.left |
padding left, unit is pts (points). |
padding.right |
padding right, unit is pts (points). |
part |
part selector, see section Part selection with the |
In PDF output, only padding.left and padding.right are supported.
padding.top and padding.bottom are ignored due to LaTeX limitations.
Global horizontal spacing can also be set with
set_table_properties(opts_pdf = list(tabcolsep = 1)).
Other formatting shortcuts:
align(),
bg(),
bold(),
color(),
empty_blanks(),
font(),
fontsize(),
highlight(),
italic(),
keep_with_next(),
line_spacing(),
rotate(),
style(),
tab_settings(),
valign()
ft_1 <- flextable(head(iris))
ft_1 <- theme_vader(ft_1)
ft_1 <- padding(ft_1, padding.top = 4, part = "all")
ft_1 <- padding(ft_1, j = 1, padding.right = 40)
ft_1 <- padding(ft_1, i = 3, padding.top = 40)
ft_1 <- padding(ft_1, padding.top = 10, part = "header")
ft_1 <- padding(ft_1, padding.bottom = 10, part = "header")
ft_1 <- autofit(ft_1)
ft_1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.