| prepend_chunks | R Documentation |
prepend chunks (for example chunk as_chunk())
in a flextable.
prepend_chunks(x, ..., i = NULL, j = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
... |
chunks to be prepended, see |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
part |
part selector, see section Part selection with the |
Other functions to compose cell content:
append_chunks(),
as_paragraph(),
compose(),
footnote(),
labelizor(),
void()
x <- flextable(head(iris))
x <- prepend_chunks(
x,
i = 1, j = 1,
colorize(as_b("Hello "), color = "red"),
colorize(as_i("World"), color = "magenta")
)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.