| use_flextable_qmd | R Documentation |
Copies the flextable-qmd Quarto extension (bundled with
flextable) into the _extensions/ directory of a
Quarto project. The extension provides Lua filters
that resolve Quarto markdown content produced by
as_qmd() inside flextable cells for HTML, PDF
and Word (docx) output formats.
After installation, add the filter to your document or project YAML:
filters: - flextable-qmd
For Word (docx) output with labelled flextable chunks
(e.g. #| label: tbl-xxx), add the post-render filter
to remove the wrapper table Quarto creates around the
flextable:
filters:
- flextable-qmd
- at: post-render
path: _extensions/flextable-qmd/unwrap-float.lua
use_flextable_qmd(path = ".", quiet = FALSE)
path |
Path to the Quarto project root. Defaults to the current working directory. |
quiet |
If |
The path to the installed extension (invisibly).
as_qmd() for creating Quarto markdown chunks,
knit_print.flextable() for rendering options in knitr documents.
Other flextable configuration:
add_latex_dep(),
use_df_printer(),
use_model_printer()
## Not run:
use_flextable_qmd()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.