| valign | R Documentation |
Change the vertical alignment of selected rows and columns of a flextable.
valign(x, i = NULL, j = NULL, valign = "center", part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
valign |
vertical alignment of paragraph within cell, one of "center" or "top" or "bottom". |
part |
part selector, see section Part selection with the |
Other formatting shortcuts:
align(),
bg(),
bold(),
color(),
empty_blanks(),
font(),
fontsize(),
highlight(),
italic(),
keep_with_next(),
line_spacing(),
padding(),
rotate(),
style(),
tab_settings()
ft_1 <- flextable(iris[c(1:3, 51:53, 101:103), ])
ft_1 <- theme_box(ft_1)
ft_1 <- merge_v(ft_1, j = 5)
ft_1
ft_2 <- valign(ft_1, j = 5, valign = "top", part = "all")
ft_2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.