vline_right: Set the right border of the table

View source: R/borders.R

vline_rightR Documentation

Set the right border of the table

Description

vline_right() draws a vertical line along the right edge of the table by setting the right border of the last column. It does not accept a column selector j because it always targets the last column.

An optional row selector i lets you restrict the line to specific rows.

Unlike vline(), which adds inner lines to the right of arbitrary columns, vline_right() is meant for the outer right edge of the table.

Usage

vline_right(x, i = NULL, border = NULL, part = "all")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

i

row selector, see section Row selection with the i parameter in <Selectors in flextable>.

border

border properties defined by a call to officer::fp_border()

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' can be used.

See Also

Other borders management: border_inner(), border_inner_h(), border_inner_v(), border_outer(), border_remove(), hline(), hline_bottom(), hline_top(), surround(), vline(), vline_left()

Examples

library(officer)
std_border <- fp_border(color = "orange")

ft <- flextable(head(iris))
ft <- border_remove(x = ft)

# add a border on the right edge of the table
ft <- vline_right(ft, border = std_border)
ft

flextable documentation built on June 2, 2026, 9:08 a.m.