add_footer_lines: Add full-width rows to the footer

View source: R/augment_rows.R

add_footer_linesR Documentation

Description

Add one or more rows to the footer where each label spans all columns (all cells merged into one). Useful for adding footnotes or source notes below the table.

Usage

add_footer_lines(x, values = character(0), top = FALSE)

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

values

a character vector or a call to as_paragraph() to get formated content, each element will be added as a new row.

top

should the row be inserted at the top or the bottom. Default to TRUE.

See Also

Other row and column operations: add_body(), add_body_row(), add_footer(), add_footer_row(), add_header(), add_header_lines(), add_header_row(), delete_columns(), delete_part(), delete_rows(), paginate(), separate_header(), set_header_footer_df, set_header_labels(), split_columns(), split_rows(), split_to_pages()

Examples

ft_1 <- flextable(head(iris))
ft_1 <- add_footer_lines(ft_1,
  values = c("blah 1", "blah 2")
)
ft_1

flextable documentation built on June 2, 2026, 9:08 a.m.