| add_header_lines | R Documentation |
Add one or more rows to the header where each label spans all columns (all cells merged into one). Useful for adding titles or subtitles above the column headers.
add_header_lines(x, values = character(0), top = TRUE)
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
values |
a character vector or a call to |
top |
should the row be inserted at the top or the bottom. Default to TRUE. |
Other row and column operations:
add_body(),
add_body_row(),
add_footer(),
add_footer_lines(),
add_footer_row(),
add_header(),
add_header_row(),
delete_columns(),
delete_part(),
delete_rows(),
paginate(),
separate_header(),
set_header_footer_df,
set_header_labels(),
split_columns(),
split_rows(),
split_to_pages()
# ex 1----
ft_1 <- flextable(head(iris))
ft_1 <- add_header_lines(ft_1, values = "blah blah")
ft_1 <- add_header_lines(ft_1, values = c("blah 1", "blah 2"))
ft_1 <- autofit(ft_1)
ft_1
# ex 2----
ft01 <- fp_text_default(color = "red")
ft02 <- fp_text_default(color = "orange")
ref <- c("(1)", "(2)")
pars <- as_paragraph(
as_chunk(ref, props = ft02), " ",
as_chunk(rep("My tailor is rich", length(ref)), props = ft01)
)
ft_2 <- flextable(head(mtcars))
ft_2 <- add_header_lines(ft_2, values = pars, top = FALSE)
ft_2 <- add_header_lines(ft_2, values = ref, top = TRUE)
ft_2 <- add_footer_lines(ft_2, values = "blah", top = TRUE)
ft_2 <- add_footer_lines(ft_2, values = pars, top = TRUE)
ft_2 <- add_footer_lines(ft_2, values = ref, top = FALSE)
ft_2 <- autofit(ft_2)
ft_2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.