| append_chunks | R Documentation |
append chunks (for example chunk as_chunk())
in a flextable.
append_chunks(x, ..., i = NULL, j = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
... |
chunks to be appened, see |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
part |
part selector, see section Part selection with the |
as_chunk(), as_sup(), as_sub(), colorize()
Other functions to compose cell content:
as_paragraph(),
compose(),
footnote(),
labelizor(),
prepend_chunks(),
void()
library(flextable)
img.file <- file.path(R.home("doc"), "html", "logo.jpg")
ft_1 <- flextable(head(cars))
ft_1 <- append_chunks(ft_1,
# where to append
i = c(1, 3, 5),
j = 1,
# what to append
as_chunk(" "),
as_image(src = img.file, width = .20, height = .15)
)
ft_1 <- set_table_properties(ft_1, layout = "autofit")
ft_1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.