Add flextable at bookmark location in a Word document
Source:R/body_add_flextable.R
body_replace_flextable_at_bkm.RdUse this function if you want to replace a paragraph containing a bookmark with a flextable. As a side effect, the bookmark will be lost.
See also
Other functions for officer integration:
body_add_flextable(),
ph_with.flextable(),
rtf_add.flextable()