Use this function if you want to replace a paragraph containing a bookmark with a flextable. As a side effect, the bookmark will be lost.
body_replace_flextable_at_bkm(
x,
bookmark,
value,
align = "center",
split = FALSE
)an rdocx object
bookmark id
flextable object
left, center (default) or right.
set to TRUE if you want to activate Word option 'Allow row to break across pages'.
Other functions for officer integration:
body_add_flextable(),
ph_with.flextable(),
rtf_add.flextable()