change borders of selected rows and columns of a flextable. This function is not to be used by end user (it requires careful settings to avoid overlapping borders) but only for programming purposes.
If you need to add borders, use instead other functions:
These set borders for the whole table : border_outer(),
border_inner_h() and border_inner_v().
To add horizontal or vertical lines in the table at specific location, use:
To add following horizontal or vertical lines at beginning or end of the table, use:
hline_top(): set the top border (outer horizontal)hline_bottom(): set the bottom border (outer horizontal)vline_left(): set the left border (outer vertical)vline_right(): set the right border (outer vertical)
If you want to highlight specific cells with some borders, use
surround().
Usage
border(
x,
i = NULL,
j = NULL,
border = NULL,
border.top = NULL,
border.bottom = NULL,
border.left = NULL,
border.right = NULL,
part = "body"
)Arguments
- x
a 'flextable' object, see flextable-package to learn how to create 'flextable' object.
- i
row selector, see section Row selection with the
iparameter in <Selectors in flextable>.- j
column selector, see section Column selection with the
jparameter in <Selectors in flextable>.- border
border (shortcut for top, bottom, left and right)
- border.top
border top
- border.bottom
border bottom
- border.left
border left
- border.right
border right
- part
part selector, see section Part selection with the
partparameter in <Selectors in flextable>. Value 'all' can be used.
Examples
library(officer)
ftab <- flextable(head(mtcars))
ftab <- border(ftab, border.top = fp_border(color = "orange"))
ftab
mpg
cyl
disp
hp
drat
wt
qsec
vs
am
gear
carb
21.0
6
160
110
3.90
2.620
16.46
0
1
4
4
21.0
6
160
110
3.90
2.875
17.02
0
1
4
4
22.8
4
108
93
3.85
2.320
18.61
1
1
4
1
21.4
6
258
110
3.08
3.215
19.44
1
0
3
1
18.7
8
360
175
3.15
3.440
17.02
0
0
3
2
18.1
6
225
105
2.76
3.460
20.22
1
0
3
1