delete_part: Delete flextable part

View source: R/augment_rows.R

delete_partR Documentation

Delete flextable part

Description

indicate to not print a part of the flextable, i.e. an header, footer or the body.

Usage

delete_part(x, part = "header")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' is not allowed by the function.

See Also

Other row and column operations: add_body(), add_body_row(), add_footer(), add_footer_lines(), add_footer_row(), add_header(), add_header_lines(), add_header_row(), delete_columns(), delete_rows(), paginate(), separate_header(), set_header_footer_df, set_header_labels(), split_columns(), split_rows(), split_to_pages()

Examples

ft <- flextable(head(iris))
ft <- delete_part(x = ft, part = "header")
ft

flextable documentation built on June 2, 2026, 9:08 a.m.