| delete_part | R Documentation |
indicate to not print a part of the flextable, i.e. an header, footer or the body.
delete_part(x, part = "header")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
part |
part selector, see section Part selection with the |
Other row and column operations:
add_body(),
add_body_row(),
add_footer(),
add_footer_lines(),
add_footer_row(),
add_header(),
add_header_lines(),
add_header_row(),
delete_columns(),
delete_rows(),
paginate(),
separate_header(),
set_header_footer_df,
set_header_labels(),
split_columns(),
split_rows(),
split_to_pages()
ft <- flextable(head(iris))
ft <- delete_part(x = ft, part = "header")
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.