| delete_rows | R Documentation |
The function removes one or more rows from a 'flextable'.
delete_rows(x, i = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
part |
part selector, see section Part selection with the |
Deleting one or more rows will result in the deletion of any span parameters that may have been set previously. They will have to be redone after this operation or performed only after this deletion.
Other row and column operations:
add_body(),
add_body_row(),
add_footer(),
add_footer_lines(),
add_footer_row(),
add_header(),
add_header_lines(),
add_header_row(),
delete_columns(),
delete_part(),
paginate(),
separate_header(),
set_header_footer_df,
set_header_labels(),
split_columns(),
split_rows(),
split_to_pages()
ft <- flextable(head(iris))
ft <- delete_rows(ft, i = 1:5, part = "body")
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.