| fix_border_issues | R Documentation |
When cells are merged, the rendered borders will be those of the first cell. If a column is made of three merged cells, the bottom border that will be seen will be the bottom border of the first cell in the column. From a user point of view, this is wrong, the bottom should be the one defined for cell 3. This function modify the border values to avoid that effect.
Note since version 0.9.7 that the function is called automatically
before rendering, user should not have to call this function anymore.
fix_border_issues(x, part = "all")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
part |
part selector, see section Part selection with the |
library(officer)
dat <- data.frame(a = 1:5, b = 6:10)
ft <- flextable(dat)
ft <- theme_box(ft)
ft <- merge_at(ft, i = 4:5, j = 1, part = "body")
ft <- hline(ft,
i = 5, part = "body",
border = fp_border(color = "red", width = 5)
)
print(ft)
ft <- fix_border_issues(ft)
print(ft)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.