View source: R/merge_flextable.R
| merge_at | R Documentation |
Merge flextable cells into a single one. All rows and columns must be consecutive.
merge_at(x, i = NULL, j = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
part |
part selector, see section Part selection with the |
Other cell merging functions:
merge_h(),
merge_h_range(),
merge_none(),
merge_v()
ft_merge <- flextable(head(mtcars), cwidth = .5)
ft_merge <- merge_at(ft_merge, i = 1:2, j = 1:2)
ft_merge
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.