| note_docx_images | R Documentation |
internal utils for roxygen tags reuse
This chunk option requires package officedown in a R Markdown
context with Word output format. With Quarto (format: docx) or
rmarkdown::word_document(), the resulting file must be repaired
with repair_docx().
PowerPoint cannot mix images and text in a paragraph, images are removed when outputing to PowerPoint format.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.