| rotate | R Documentation |
It can be useful to change the text direction when table headers are large. For example, header labels can be rendered as "tbrl" (top to bottom and right to left), corresponding to a 90-degree rotation, or "btlr", corresponding to a 270-degree rotation. This function changes cell text direction. By default, it is "lrtb", which means from left to right and top to bottom.
'Word' and 'PowerPoint' do not handle automatic height with rotated headers.
Therefore, you need to set header heights (with the height() function)
and set the rule to "exact" for row heights (with the hrule() function);
otherwise, Word and PowerPoint outputs will have insufficient height
to properly display the text.
flextable does not rotate text by arbitrary angles. It only rotates by right angles (90-degree increments). This choice ensures consistent rendering across Word, PowerPoint (limited to angles 0, 270, and 90), HTML, and PDF.
rotate(x, i = NULL, j = NULL, rotation, align = NULL, part = "body")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
j |
column selector, see section Column selection with the |
rotation |
one of "lrtb", "tbrl", "btlr". |
align |
vertical alignment of paragraph within cell, one of "center" or "top" or "bottom". |
part |
part selector, see section Part selection with the |
When the autofit() function is used, rotation will be
ignored. In that case, use dim_pretty and width instead
of autofit().
Other formatting shortcuts:
align(),
bg(),
bold(),
color(),
empty_blanks(),
font(),
fontsize(),
highlight(),
italic(),
keep_with_next(),
line_spacing(),
padding(),
style(),
tab_settings(),
valign()
library(flextable)
ft_1 <- flextable(head(iris))
ft_1 <- rotate(ft_1, j = 1:4, align = "bottom", rotation = "tbrl", part = "header")
ft_1 <- rotate(ft_1, j = 5, align = "bottom", rotation = "btlr", part = "header")
# if output is docx or pptx, think about (1) set header heights
# and (2) set rule "exact" for rows heights because Word
# and PowerPoint don't handle auto height with rotated headers
ft_1 <- height(ft_1, height = 1.2, part = "header")
ft_1 <- hrule(ft_1, i = 1, rule = "exact", part = "header")
ft_1
dat <- data.frame(
a = c("left-top", "left-middle", "left-bottom"),
b = c("center-top", "center-middle", "center-bottom"),
c = c("right-top", "right-middle", "right-bottom")
)
ft_2 <- flextable(dat)
ft_2 <- theme_box(ft_2)
ft_2 <- height_all(x = ft_2, height = 1.3, part = "body")
ft_2 <- hrule(ft_2, rule = "exact")
ft_2 <- rotate(ft_2, rotation = "tbrl")
ft_2 <- width(ft_2, width = 1.3)
ft_2 <- align(ft_2, j = 1, align = "left")
ft_2 <- align(ft_2, j = 2, align = "center")
ft_2 <- align(ft_2, j = 3, align = "right")
ft_2 <- valign(ft_2, i = 1, valign = "top")
ft_2 <- valign(ft_2, i = 2, valign = "center")
ft_2 <- valign(ft_2, i = 3, valign = "bottom")
ft_2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.