Apply formatter functions to column keys.
Functions should have a single argument (the vector) and should return the formatted values as a character vector.
Arguments
- x
a 'flextable' object, see flextable-package to learn how to create 'flextable' object.
- ...
Name-value pairs of functions, names should be existing col_key values
- values
format functions, If values is supplied argument
...is ignored.It can be a list of name-value pairs of functions, names should be existing col_key values.
If
valuesis a single function, it will be applied to each column.
- part
part selector, see section Part selection with the
partparameter in <Selectors in flextable>. Value 'all' is not allowed by the function.
See also
Other cells formatters:
colformat_char(),
colformat_date(),
colformat_datetime(),
colformat_double(),
colformat_image(),
colformat_int(),
colformat_lgl(),
colformat_num()
Examples
ft <- flextable(head(iris))
ft <- set_formatter(
x = ft,
Sepal.Length = function(x) sprintf("%.02f", x),
Sepal.Width = function(x) sprintf("%.04f", x)
)
ft <- theme_vanilla(ft)
ft
Sepal.Length
Sepal.Width
Petal.Length
Petal.Width
Species
5.10
3.5000
1.4
0.2
setosa
4.90
3.0000
1.4
0.2
setosa
4.70
3.2000
1.3
0.2
setosa
4.60
3.1000
1.5
0.2
setosa
5.00
3.6000
1.4
0.2
setosa
5.40
3.9000
1.7
0.4
setosa