Split a flextable into a list of flextables whose columns fit within a given width (in inches). This is useful for paginating wide tables in Word or PowerPoint output.
Arguments
- x
a 'flextable' object, see flextable-package to learn how to create 'flextable' object.
- max_width
Maximum width for each page (in inches by default).
- rep_cols
Columns to repeat on every page. Can be a character vector of column names or an integer vector of column positions.
NULL(default) means no repetition. Repeated columns appear at the beginning of each page in the order specified.- unit
Unit for
max_width, one of"in","cm","mm".
See also
Other row and column operations:
add_body(),
add_body_row(),
add_footer(),
add_footer_lines(),
add_footer_row(),
add_header(),
add_header_lines(),
add_header_row(),
delete_columns(),
delete_part(),
delete_rows(),
paginate(),
separate_header(),
set_header_footer_df,
set_header_labels(),
split_rows(),
split_to_pages()