Skip to contents

vline() draws a vertical line to the right of each selected column by setting the right border of cells at column j (and the left border of cells at column j + 1 so that the line renders consistently across output formats).

Use the j selector to target specific columns. When j is NULL (the default) the border is added to the right of every column, producing a full grid of inner vertical lines.

For the outer edges of the table, use vline_left() and vline_right() instead; those always target the very first or very last column.

Usage

vline(x, i = NULL, j = NULL, border = NULL, part = "all")

Arguments

x

a 'flextable' object, see flextable-package to learn how to create 'flextable' object.

i

row selector, see section Row selection with the i parameter in <Selectors in flextable>.

j

column selector, see section Column selection with the j parameter in <Selectors in flextable>.

border

border properties defined by a call to officer::fp_border()

part

part selector, see section Part selection with the part parameter in <Selectors in flextable>. Value 'all' can be used.

Examples

library(officer)
std_border <- fp_border(color = "orange")

ft <- flextable(head(iris))
ft <- border_remove(x = ft)

# add vertical borders to the right of every column
ft <- vline(ft, border = std_border)
ft

Sepal.Length

Sepal.Width

Petal.Length

Petal.Width

Species

5.1

3.5

1.4

0.2

setosa

4.9

3.0

1.4

0.2

setosa

4.7

3.2

1.3

0.2

setosa

4.6

3.1

1.5

0.2

setosa

5.0

3.6

1.4

0.2

setosa

5.4

3.9

1.7

0.4

setosa