| vline_right | R Documentation |
vline_right() draws a vertical line along the right edge
of the table by setting the right border of the last column.
It does not accept a column selector j because it always
targets the last column.
An optional row selector i lets you restrict the line to
specific rows.
Unlike vline(), which adds inner lines to the right of
arbitrary columns, vline_right() is meant for the outer
right edge of the table.
vline_right(x, i = NULL, border = NULL, part = "all")
x |
a 'flextable' object, see flextable-package to learn how to create 'flextable' object. |
i |
row selector, see section Row selection with the |
border |
border properties defined by a call to
|
part |
part selector, see section Part selection with the |
Other borders management:
border_inner(),
border_inner_h(),
border_inner_v(),
border_outer(),
border_remove(),
hline(),
hline_bottom(),
hline_top(),
surround(),
vline(),
vline_left()
library(officer)
std_border <- fp_border(color = "orange")
ft <- flextable(head(iris))
ft <- border_remove(x = ft)
# add a border on the right edge of the table
ft <- vline_right(ft, border = std_border)
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.